breed                 [donothing]              ;; to avoid id 0 in network download in case of matlab or other programs to use
breed                 [socs soc]               ;; social entities of the system
breed                 [ecols ecol]             ;; ecological entities of the system
undirected-link-breed [sss ss]                 ;; social edges (connection between social entities: represent possibility of knowledge transfer)
undirected-link-breed [eee ee]                 ;; ecological edges (connection between ecological entities: represent possibility of pest diffusion)
undirected-link-breed [ssseee ssee]            ;; social-ecological edges (connection between social and ecological entities: time-delay and possibility to act with immunization)

socs-own              [strategy                ;; type of strategy, if immunization is used or not. 0 if not used, and 1 if used
                       solo                    ;; if a soc is isolated
                       income                  ;; amnount of income generated by yields
                       pastincome              ;; average of income of the last n timesteps
                       pastlist                ;; list with strategy-income correspondence
                       incomelist              ;; the list from which pastincome is averaged from
                       payoff                  ;; payoff of social nodes calculated as income - cost
                       harvest                 ;; same as yield but needed for programming purposes to calculate income
                       changed                 ;; if strategy has changed from the previous time step
                       strat1                  ;; counter for how many times strategy 0 lead to above avg results
                       strat0                  ;; counter for how many times strategy 0 lead to above avg results
                       changing                ;; attitude to change strategy depending on payoffs of prevoius rounds
                       oldstrat                ;; to check for the amount of changes in strategy done
                       deltapay                ;; difference between one own income and neighbors income for success bias imitation
                       payofflist              ;; payoff list
                       learning?               ;; type of learning used by an agent
                       learnind                ;; times individual learning has been used
                       learnsuc                ;; times success learning has been used
                       learnconf               ;; times conformist learning has been used
                      ]                
ecols-own             [pestres                 ;; pest resistance 
                       maxyield                ;; beggining of the simulation yield or maximum possible yield for a specific ecological node
                       yield                   ;; yield from each ecological node
                       infected                ;; if node is infected
                       immune                  ;; if the node is immune from infection or not
                       distime                 ;; time disease last if caught, even under immunization it is reduced by 1 anytime treatment is applied (or immunization is applied)
                       timmune                 ;; counter for how long immunization lasts (depends on timm in the interface)
                       flagimm                 ;; flag to avoid that immunization is cumulative but NOT IN USE FOR NOW
                      ]
eee-own               [geodist
                      ] 
sss-own               [rewired?
                      ]
turtles-own           [location                ;; variable needed to link social and ecological entities in a one-to-one exclusive relationshipd for social-ecological edges
                       degree                  ;; number of connected nodes (ecological only ecological and for social only social count)
                      ]

globals               [ adopters               ;; number of adopters (social nodes) average of the last 100 ts
                        adopters1              ;; avg adopters of the last (max 100 ts) before eradication. count adopters at eradication of pest
                        shortadopters          ;; adopters just 5 ts before eradication (average)
                        infection              ;; number of infected ecological nodes
                        sumchanges             ;; number of strategy switching in the last 100 time steps
                        sumchanges1            ;; number of strategy switching in the last N time steps (max 100) before eradication of pest
                        time                   ;; time variable  
                        avgpayoff              ;; average payoff of the whole group 
                        minpayoff              ;; minimum payoff for the group
                        maxpayoff              ;; maximum payoff for the group
                        changes                ;; number of turtles switching strategy in a given time-step
                        timetoerad             ;; in case of pest eradication, time needed for
                        name
                        netime
                        filename
                        avgpayofflist
                        minpayofflist
                        maxpayofflist
                        adopterslist
                        adopterslist1
                        shortadoptlist1
                        infectionlist
                        changelist             
                        changelist1
                        learnindlist1
                        learnconflist1
                        learnsuclist1              
                        learnind1              ;; average times individual learning is used for the last x time-steps before eradicatino (if it happens)
                        learnconf1             ;; avg times conformist learning is used used for the last x time-steps before eradicatino (if it happens)
                        learnsuc1              ;; avg times success learning is used used for the last x time-steps before eradicatino (if it happens)
                        learnind2              ;; average times individual learning is used (divide by 1000 to find avg per time-step at t-s 1000
                        learnconf2             ;; average times conformist learning is used (divide by 1000 to find avg per time-step at t-s 1000
                        learnsuc2              ;; average times success learning is used (divide by 1000 to find avg per time-step at t-s 1000
                        timetoeradlist         ;; if happens, time to eradicate pest
                        isolates               ;; number of isoalted social nodes 
                        conform                ;; number of socs that follow conformist strategy
                        success                ;; number of socs that follow success bias strategy
                        geo                    ;; used to build the ecological network
                        degrees                ;; used for the scale free network building
                        new-node               ;; used in the scale free procedure
                     
                        
                        prova2                   ;; debug global
                        prova3 
                      ]

;;;;OTHER VARIABLES REPRESENTED IN THE INTERFACE TAB

; nodes              = number of social and ecological entitites  (assumption here is that 1 ecol is always managed by 1 soc 
; socnet?            = type of social network: random (E edges placed randomly), small world (with lattice of dimension D and then rew-prob), scale free and correlated (1 to 1 correspondence between ecol and soc connectivity)
; numsss             = number of edges placed randomly in the social system
; lattice            = initial lattice dimension for small world networks
; rew-prob           = rewiring probability in small world networks (prob of 1 is basically a random network)
; m                  = initial social nodes placed initially to build the scale free network
; pref-prob          = probability of attaching preferentially to older nodes
; numeee             = number of edges connecting the ecological system (that is connected via geoprox, thus smalle network correspond also to lower diffusion dynamics.
; recovery           = gain of yield due to recovery in production and pest eradication
; eff                = loss of yield due to infection
; adopt-th           = adoption threshold equal for all socs, works under conformist learning strategy
; avgpr              = average pest resistance
; sdpr               = standard deviation of pest resistance
; initialinf         = number of nodes initially infected
; mu                 = error in the learning procedure (or mutation)
; mult               = price of crop, or yield multiplier that allows to generate income
; memory             = how many time-steps are used to form income comparison with current income.
; cost               = cost of strategy 
; learningprob       = learning type probability, if success or conformist
; resist?            = if pest resistant is constant, uniformly distributed or normally distributed with mean avgpr and standard deviation sdpr.
; rents?             = if yield is constant, uniformly distributed or normally distributed with mean avgyield and standard deviation sdyield
; timedis            = time that the disease will persist, under constant treatment. If treatment finishes, it will start again and it will take again timedis timesteps to get rid of it
; timm               = time immunization lasts  -- half implemented
; confid             = confidence in one own learning (threshold needed to go to social learning) (where 0 means that i can do always my own learning and increases as decreases confidence in one-self)

;NOT IN USE AS OF NOW
; delay              = time delay from ecol pest and social node to know that there is a problem  

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;MODEL MAIN PROCEDURES (SETUP AND DYNAMICS);;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all

  setup-ecol-net
  setup-soc-net

  setup-dep
  setup-initial-infection
  setup-begin-metrics
;  export-network
  reset-ticks
end

to go
   let eradicate count ecols with [infected  = 1]
   if eradicate > 0 [
     set adopterslist1 fput adopters adopterslist1
     set shortadoptlist1 fput adopters shortadoptlist1
     if length shortadoptlist1 > 5 [set shortadoptlist1 remove-item 5 shortadoptlist1]
     set changelist1 fput changes changelist1
     set learnindlist1 fput mean [learnind] of socs learnindlist1
     if length learnindlist1 > 1 [set learnindlist1 remove-item 1 learnindlist1]
     set learnconflist1 fput mean [learnconf] of socs learnconflist1
     if length learnconflist1 > 1 [set learnconflist1 remove-item 1 learnconflist1]
     set learnsuclist1 fput mean [learnsuc] of socs learnsuclist1
     if length learnsuclist1 > 1 [set learnsuclist1 remove-item 1 learnsuclist1]     
     set timetoeradlist fput ticks timetoeradlist
     if length timetoeradlist > 1 [set timetoeradlist remove-item 1 timetoeradlist]
   ]
   set avgpayofflist fput avgpayoff avgpayofflist
   set minpayofflist fput minpayoff minpayofflist
   set maxpayofflist fput maxpayoff maxpayofflist
   set adopterslist fput adopters adopterslist
   set infectionlist fput infection infectionlist
   set changelist fput changes changelist
   
   if ticks > 100 [
     set avgpayofflist remove-item 100 avgpayofflist
     set minpayofflist remove-item 100 minpayofflist
     set maxpayofflist remove-item 100 maxpayofflist
     set adopterslist  remove-item 100 adopterslist
     set infectionlist remove-item 100 infectionlist
     set changelist remove-item 100 changelist
   ]
   if eradicate = 0  [
     set adopters1 mean adopterslist1
     set shortadopters mean shortadoptlist1
     set sumchanges1 sum changelist1
     set timetoerad mean timetoeradlist     
     set learnind1 mean learnindlist1
     set learnconf1 mean learnconflist1
     set learnsuc1 mean learnsuclist1
   ]
   if ticks > 1000  [
    set avgpayoff mean avgpayofflist
    set minpayoff mean minpayofflist
    set maxpayoff mean maxpayofflist
    set adopters mean adopterslist
    set infection mean infectionlist
    set sumchanges sum changelist
    set learnind2 mean [learnind] of socs
    set learnconf2 mean [learnconf] of socs
    set learnsuc2 mean [learnsuc] of socs
    
;    ask socs [
;      output-type "who am i :"
;      output-type who
;      output-type " ind: "
;      output-type learnind
;      output-type " conf: "
;      output-type learnconf
;      output-type " succ: "
;      output-print learnsuc
;    ]
      
    stop
   ]
  infection-diffusion    
  learn
  errorlearning
  effects        ;not in use
  payoff-calc
  output-calc
  tick
end



;;; make in such a way that ecol net is geoprox.



;;;;;;;;SETUP PROCEDURES;;;;;;;;;;;;;;;;;;SETUP PROCEDURES;;;;;;;;;;;;;;;;;;SETUP PROCEDURES;;;;;;;;;;;;;;;;;;SETUP PROCEDURES;;;;;;;;;;;;;;;;;;SETUP PROCEDURES;;;;;;;;;;
to setup-soc-net
  
  if socnet? = "random"[
    create-socs nodes
    ask socs[
      set color red
      set shape "circle"
      set size 2
      setxy random-xcor random-float max-pycor
      set location [who] of self
      set location location - nodes
      set strategy 0
      set pastlist []
      set incomelist []
      ifelse random-float 1 < learnprob
      [set learning? "success"]
      [set learning? "conformist"]
    ]
      while [count sss < numsss] [
        ask one-of socs [create-ss-with one-of other socs]
      ]
  ]
  ;; lattice of specific d (from 1 to 5) is chosen, than some edges are rewired with probability rew-prob
  if socnet? = "small-world" [
    create-socs nodes
    ask socs[
      set color red
      set shape "circle"
      set size 2
      setxy random-xcor random-float max-pycor
      set location [who] of self
      set location location - nodes
      set strategy 0
      set pastlist []
      set incomelist []
      ifelse random-float 1 < learnprob
      [set learning? "success"]
      [set learning? "conformist"]
    ]
    ;; lattice 1 = nodes edges, 2 = 2*nodes etc (max number, fully connected network)
    wire-them
    ask sss [
      ;rewiring
      if (random-float 1) < rew-prob[
        let soc1 end1
        ;; if "a" is not connected to everybody
        if [ count link-neighbors ] of end1 < (count turtles - 1)[
          ;; find a node distinct from node1 and not already a neighbor of node1
          let soc2 one-of socs with [ (self != soc1) and (not link-neighbor? soc1) ]
          if soc2 != nobody [
            ask soc1 [ create-ss-with soc2 [ set color green  set rewired? true ] ]
            set rewired? true
          ]
        ]
      ]
      ;need to remove the old edge, as we are rewiring and not adding
      if (rewired?) [
        die
      ]
    ]
  ]
  ;;albert-barabasi scale free networks
  if socnet? = "scale-free" [
    set degrees []
    create-socs m [
      set color red
      set shape "circle"
      set size 2
      setxy random-xcor random-float max-pycor
      set location [who] of self
      set location location - nodes
      set strategy 0
      set pastlist []
      set incomelist []
      ifelse random-float 1 < learnprob
      [set learning? "success"]
      [set learning? "conformist"]
    
    ]
    ask socs [
      repeat m [set degrees lput self degrees]
      ask other socs with [not link-neighbor? myself] [
        create-ss-with myself
      ]
    ]
    let partner nobody
    while [count socs < nodes] [
      create-socs 1 [
        set color red
        set shape "circle"
        set size 2
        setxy random-xcor random-float max-pycor
        set location [who] of self
        set location location - nodes
        set strategy 0
        set pastlist []
        set incomelist []
        ifelse random-float 1 < learnprob
        [set learning? "success"]
        [set learning? "conformist"]
        set new-node self
        repeat m [
          ifelse (random-float 1 < prob-pref) 
          [
            set partner new-node
            while [partner = new-node] [
              set partner one-of degrees
              ask partner [
                if link-neighbor? self [
                  set partner new-node
                ]
              ]
            ]
          ]
          [
            set partner one-of socs with [(not link-neighbor? self) and (self != myself)]
          ]
          create-ss-with partner
          set degrees lput new-node degrees
          set degrees lput partner degrees
        ]
      ]
    ]
  ]
  if socnet? = "correlated"[
    create-socs nodes
    ask socs[
      set color red
      set shape "circle"
      set size 2
      setxy random-xcor random-float max-pycor
      set location [who] of self
      set location location - nodes
      set strategy 0
      set pastlist []
      set incomelist []
      ifelse random-float 1 < learnprob
      [set learning? "success"]
      [set learning? "conformist"]
    
    ]
  ]
  ask sss [
    set color red
    set thickness 0.5
  ] 
  
  ask sss [
    set color red
    set thickness 0.5
  ] 
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-ecol-net
  ;;setting up of ecological nodes
  create-ecols nodes
  ask ecols [
    set color white
    set shape "circle"
    set size 2
    setxy random-xcor random-float min-pycor
    
    ;; depending on type of pest resistance distribution we set pest resistance of the ecological nodes
    ifelse resist? = "normal" 
    [
      set pestres random-normal avgpr sdpr
      if pestres > 1 [set pestres 1]
      if pestres < 0 [set pestres 0]
    ]
    [
      ifelse resist? = "uniform"
      [
        set pestres random-float 1 
      ]
    [
      if resist? = "constant"[  ;;we can potentially add N gradients as there are in real and draw numbers for pest resistance according to gradients.
        set pestres resistlev
      ]
    ]
    ]
    ;; depending on the type of yield distribution we set the yield of the ecological nodes 
    ifelse rents? = "normal" 
    [
      set yield random-normal avgyield sdyield
      if yield < 0 [set yield 0]
    ]
    [
      ifelse rents? = "uniform"
      [
        set yield random 100
      ]
    [
      if rents? = "constant"[  ;; 
        set yield yieldlev
      ]
    ]
    ]
    set maxyield yield
    set location [who] of self

  ]
  ;; setting up of ecological edges  
  
;; creates a network based on geographical proximity with N nodes and edges in the interval [0, N(N-1)/2]

  ask ecols [
    create-eee-with other ecols
  ]
  set geo (list)
  ask eee [
    set geodist link-length
    set geo fput geodist geo
    ]  
  set geo sort geo
  while [count eee > numeee] [
    ask eee with [geodist = last geo] [
      die
    ]
    set geo remove last geo geo

  ]    
  ask eee [
    set color white
    set thickness 0.5
  ]
end

to setup-dep 
  ;; setting up the social-ecological interdependence
  ask ecols [
    create-ssseee-with socs with [[location] of myself = [location] of self]
  ]
  ask ssseee[
    set color blue
    set thickness 0.5
  ]
  if socnet? = "correlated" [
    ask socs [
      let partners []
      let partner2 []
      ask ssee-neighbors [
        if any? ee-neighbors [
          set partners ee-neighbors
          set partner2 fput [[location] of ssee-neighbors] of ee-neighbors partner2
        ]
      ]
      if not empty? partner2 [
        let nodal item 0 item 0 partner2
        create-ss-with soc (item 0 nodal + nodes)
        set partner2 remove-item 0 item 0 partner2
      ]
      while [not empty? partner2][
        let nodal item 0 item 0 partner2
        create-ss-with soc (nodal + nodes)
        set partner2 remove-item 0 partner2
      ]
    ]
  ]
  ask sss [
    set color red
    set thickness 0.5
  ] 
end

to wire-them ;; small world procedure, building lattices
  ;; iterate over the turtles
  let nx nodes
  while [nx < count socs + nodes]
  [
    ;; make edges with the next two neighbors
    ;; this makes a lattice with average degree of 4
    let soc0 soc nx 
    let lat 1
    while [lat <= lattice] [
      ask soc0 [
        create-ss-with soc ((nx + lat) mod count socs + nodes)
      ]
      set lat lat + 1
    ]
   ; let soc1 soc ((nx + 1) mod count socs + nodes)
   ;  ask soc0 [
   ;   create-ss-with soc1
   ; ]
     ask sss [set rewired? false]     
     set nx nx + 1
   ]
  
end

to setup-initial-infection
  ask n-of initialinf ecols [
    set infected 1
    set color cyan
  ]
end

to setup-begin-metrics
  set adopters count socs with [strategy = 1] / nodes
  set adopters precision adopters 3
  set infection count ecols with [infected = 1] / nodes
  set infection precision infection 3
  set avgpayofflist []
  set minpayofflist []
  set maxpayofflist []
  set adopterslist []
  set infectionlist []
  set changelist []
  set adopterslist1 []
  set shortadoptlist1[]
  set changelist1 []
  set timetoeradlist []
  set learnindlist1 []
  set learnconflist1 []
  set learnsuclist1 []
  ask socs [if count ss-neighbors = 0 [ set solo 1]]
  set isolates sum [solo] of socs
end



;;;;;;;;;;;;;;DYNAMICS PROCEDURES;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DYNAMICS PROCEDURES;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DYNAMICS PROCEDURES;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DYNAMICS PROCEDURES;;;;;;;;;;;;;;;


to infection-diffusion
  ;; infection of pest on land 
  ask ecols [set timmune timmune - 1] ;; this because we want immunization to last more than 1 round or 1 round, now we add flexibility here
  
  ask ecols with [infected = 1] [
    ask ee-neighbors with [immune = 0][ 
        if pestres < random-float 1 [ 
        set infected  1
        set color cyan
        set yield yield - eff
        if yield < 0 [set yield 0]
        set distime timedis              
      ]
    ]
  ]
  ask ecols with [immune = 1] [
    set distime distime - 1
    if distime < 1 [
      set infected 0
      set color white
      set yield yield + recovery
     if yield > maxyield [set yield maxyield]
    ]
  ]
end

to learn
  ;; reporting strategy before learning to count the number of strategy changes
  ask socs [set strategy oldstrat]
  ;; own learning or probability of switching strategy depending on pastincome and current income
  ask socs [
    ifelse not any? ss-neighbors 
    [ 
      set learnind learnind + 1
      ifelse strat0 + strat1 = 0 
      [
        ifelse random-float 1 < 0.5 [set strategy 0] [set strategy 1]
      ]
      [
        let pstrat strat0 / (strat0 + strat1)
        ifelse random-float 1 < pstrat [set strategy 0] [set strategy 1]
        ifelse strategy = 1 
          [
            ask ssee-neighbors [
              set immune 1
              set timmune timm
            ]
          ]
        [
          ask ssee-neighbors [
            if timmune < 1 [
              set immune 0
            ]
          ]
        ]
      ]
    ]
    [
     ;; starting success bias imitation strategy for strategy adoption and immunization ;; also check how the individual learning here will influence the probability of social-learning.
     if learning? = "success" [
      ifelse abs strat0 - strat1 >= confid 
      [
        set learnind learnind + 1
        ifelse strat0 + strat1 = 0 
        [
          ifelse random-float 1 < 0.5 [set strategy 0] [set strategy 1]
        ]
        [
          let pstrat strat0 / (strat0 + strat1)
          ifelse random-float 1 < pstrat [set strategy 0] [set strategy 1]        
          ifelse strategy = 1 
          [
            ask ssee-neighbors [
              set immune 1
              set timmune timm
            ]
          ]
          [
            ask ssee-neighbors [
              if timmune < 1 [
                set immune 0
              ]
            ]
          ]
        ]
      ]
      [ ;output-print "DO SUCCESS"
        set learnsuc learnsuc + 1
        set payofflist []
        set payofflist [payoff] of ss-neighbors with [strategy != [strategy] of myself]
        ifelse empty? payofflist 
        [
          set deltapay 0
        ]
        [
          set deltapay max payofflist - [payoff] of self 
         ;if deltapay > 8  [set deltapay 8]
         ;if deltapay < -8 [set deltapay -8]
        ]

        if random-float 1 < (1 / (1 + e ^ (- deltapay))) [
          ifelse strategy = 0 
          [ 
            set strategy 1
            ask ssee-neighbors [
              set immune 1
               set timmune timm
             ]
           ]
           [
             set strategy 0
             ask ssee-neighbors [
               if timmune < 1 [
                 set immune 0
               ]
             ]
           ]
         ]
       ]
     ]
     if learning?  = "conformist" [ ;;; starting the conformist bias imitation strategy for adoption, need the zefferman equation in alternative we can use the threshold value and change the threhold of adopt percentage needed to switch
       ifelse abs (strat0 - strat1) >= confid 
       [ set learnind learnind + 1
         ifelse strat0 + strat1 = 0 
         [
           ifelse random-float 1 < 0.5 [set strategy 0] [set strategy 1]
         ]
         [
           let pstrat strat0 / (strat0 + strat1)
           ifelse random-float 1 < pstrat [set strategy 0] [set strategy 1]        
           ifelse strategy = 1 
           [
             ask ssee-neighbors [
               set immune 1
               set timmune timm
             ]
           ]
          [
             ask ssee-neighbors [
               if timmune < 1 [
                 set immune 0
               ]
             ]
           ]
         ]
       ]
       [ ;output-print "DO CONFORM"
         set learnconf learnconf + 1
         let s0 count ss-neighbors with [strategy = 0]
         let s1 count ss-neighbors with [strategy = 1]
         let pr0 ( (s0 ^ th) / ( (s1 ^ th) + (s0 ^ th)) ) 

         ifelse random-float 1 < pr0 [set strategy 0] [set strategy 1]
         ifelse strategy = 1 
         [
           ask ssee-neighbors [
            set immune 1
            set timmune timm
          ]
         ]
         [
           ask ssee-neighbors [
             if timmune < 1 [
               set immune 0
             ]
           ]
         ]

       ]
     ]
    ]
  ]
end

to errorlearning
  ;; mutation part of the learning/cultural selection algorithm
  ask socs [
    ifelse strategy = 1 
    [
      if random-float 1 < mu [
        set strategy 0
        ask ssee-neighbors [
          if timmune < 1 [
            set immune 0 
          ]
        ]
      ]
    ]
    [
      if random-float 1 < mu [
        set strategy 1
        ask ssee-neighbors [
          set immune 1
          set timmune timm
        ]
      ]
    ]
  ]
end

to effects
  ;; checking times with timedis and distime of immunization, not a choice, just how immunization affects the rest i think not sure if to use it now
;;PSEUDOCODE FOR NOW
;; if ecols in timm then avoid change immunization and diffusion, keep it immunized even if the social node stops treatment, not sure how this plays, just 
;; a thought place holder for now.
;; still all of this is implemented throughout the code, so no need for this procedure anymore i guesss... but keep it as placeholder.

end

to payoff-calc 
  ;clear-output
  ask socs [
    set harvest [yield] of one-of ssee-neighbors
    set income (harvest * multi) - (strategy * cost)  ;; if timm is increased, the actual cost per strategy is decreased and benefits are good... not sure here... a bit confusing for now.
    set payoff income
    let buildlist []                       ;;; this buildlist allows for correspondence between income and strategy of that round... it is not perfect, but it is a good start
    set buildlist fput income buildlist
    set buildlist fput strategy buildlist
    set pastlist fput buildlist pastlist
    set incomelist fput income incomelist
    if length pastlist > memory [
      set pastlist remove-item memory pastlist  ;; here comes in the memory for strategy decision...the lenght of past income one remembers depends on memory
      set incomelist remove-item memory incomelist
    ]
    ;;; the following bit of code needs to be realted to how successful they have been in the past comapred to an average given by avglist depending on the strategy adopted.
    set strat0 0  ;;avoid division by 0
    set strat1 0
    let avglist mean incomelist
    let z length pastlist
    let i 0 
    while [i < z] 
    [
      let a item 1 item i pastlist 
      let b item 0 item i pastlist
      let delta a - avglist
      ifelse delta > 0 
      [
        ifelse b > 0
        [
          set strat1 strat1 + 1
        ]
        [ 
          set strat0 strat0 + 1
        ]
      ]
      [
        ifelse b > 0 
        [
          set strat1 strat1 ;- 1
        ]
        [
          set strat0 strat0 ;- 1
        ]   
      ] 
      set i i + 1
    ]
  ;  output-type who
  ;  output-type "; strat0; "
  ;  output-type strat0
  ;  output-type "; strat1; "
  ;  output-print strat1
  ]
end

to output-calc
  ask socs [ ifelse oldstrat = strategy [set changed 0] [set changed 1]]
  set adopters count socs with [strategy = 1] / nodes
  set adopters precision adopters 3
  set infection count ecols with [infected = 1] / nodes
  set infection precision infection 3
  set avgpayoff mean [payoff] of socs 
  set minpayoff min [payoff] of socs   
  set maxpayoff max [payoff] of socs 
  set changes sum [changed] of socs

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;REPORTING THE NETWORK;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report pad [ number digits ]
  let expanded ( word "000000000000000" number )
  let len length expanded
  report substring expanded ( len - digits ) len
end

to-report next-log-filename [ prefix digits suffix]
;; report the first filename that does not exist
 let next-id# 0
 let next-id$ ""
 let keep-looking? true
 while [ keep-looking? ]
   [ set next-id# next-id# + 1
     set next-id$ ( word prefix ( pad next-id# digits ) suffix )
     set keep-looking? file-exists? next-id$
   ]
report next-id$
end

to export-network
   set name new-seed
    random-seed name                                            
    let z random 10000
    set netime date-and-time
    set netime remove ":" netime
    set netime remove "." netime
    set netime substring netime 0 10
    set netime word z netime
    set filename next-log-filename netime 5 ".txt"  
    file-open filename
      let blank "   "
      let namenodes [who] of turtles
      let nnodes max [who] of turtles
      file-type "*Vertices" 
      file-type ";" 
      file-print nnodes
      file-print "*Arcs"
      ask turtles   [
        let neigh link-neighbors
        if (count neigh) > 0 [
          foreach [who] of neigh [
            file-type who
            file-type ";"
            file-type  ?
            file-type ";"
            file-print 1
          ]
        ]
      ]
          
  file-close
end
@#$#@#$#@
GRAPHICS-WINDOW
871
12
1238
400
60
60
2.9504132231405
1
10
1
1
1
0
0
0
1
-60
60
-60
60
0
0
1
ticks
30.0

BUTTON
11
10
74
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
77
10
140
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
145
10
208
43
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
15
51
187
84
nodes
nodes
0
100
10
10
1
NIL
HORIZONTAL

SLIDER
249
95
421
128
multi
multi
1
5
1
0.1
1
NIL
HORIZONTAL

SLIDER
423
95
595
128
numeee
numeee
0
nodes * (nodes - 1) / 2
10
5
1
NIL
HORIZONTAL

SLIDER
423
168
595
201
avgpr
avgpr
0
1
0
0.01
1
NIL
HORIZONTAL

SLIDER
423
204
595
237
sdpr
sdpr
0
10
0
0.1
1
NIL
HORIZONTAL

CHOOSER
356
10
494
55
resist?
resist?
"normal" "uniform" "constant"
2

SLIDER
421
240
593
273
resistlev
resistlev
0
1
0
0.01
1
NIL
HORIZONTAL

SLIDER
249
131
421
164
delay
delay
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
424
132
596
165
initialinf
initialinf
0
nodes
1
1
1
NIL
HORIZONTAL

SLIDER
423
277
595
310
timm
timm
0
100
5
1
1
NIL
HORIZONTAL

SLIDER
607
97
779
130
eff
eff
1
50
10
1
1
NIL
HORIZONTAL

SLIDER
247
167
419
200
mu
mu
0
0.1
0.01
0.01
1
NIL
HORIZONTAL

CHOOSER
499
10
637
55
rents?
rents?
"constant" "uniform" "normal"
0

SLIDER
603
204
775
237
avgyield
avgyield
0
100
100
10
1
NIL
HORIZONTAL

SLIDER
603
242
775
275
sdyield
sdyield
0
10
2
0.1
1
NIL
HORIZONTAL

SLIDER
603
277
775
310
yieldlev
yieldlev
0
200
100
10
1
NIL
HORIZONTAL

SLIDER
247
202
419
235
memory
memory
1
100
5
1
1
NIL
HORIZONTAL

MONITOR
778
22
850
67
Immunized
count ecols with [immune = 1] / count ecols
17
1
11

MONITOR
779
71
850
116
adopters
adopters
5
1
11

SLIDER
605
134
777
167
th
th
0
5
8
1
1
NIL
HORIZONTAL

MONITOR
779
118
851
163
Infected
infection
5
1
11

SLIDER
243
239
415
272
cost
cost
0
100
10
1
1
NIL
HORIZONTAL

SLIDER
203
10
355
43
learnprob
learnprob
0
1
1
0.01
1
NIL
HORIZONTAL

SLIDER
606
168
778
201
recovery
recovery
0
100
10
1
1
NIL
HORIZONTAL

MONITOR
779
164
852
209
NIL
avgpayoff
17
1
11

MONITOR
778
214
853
259
NIL
minpayoff
5
1
11

MONITOR
778
263
853
308
NIL
maxpayoff
5
1
11

PLOT
144
367
478
595
Payoff Distribution (min max and avg)
NIL
NIL
0.0
1.0
-10.0
10.0
true
true
"" ""
PENS
"avg" 1.0 0 -16777216 true "" "plot avgpayoff"
"min" 1.0 0 -14454117 true "" "plot minpayoff"
"max" 1.0 0 -2674135 true "" "plot maxpayoff"

PLOT
481
363
861
595
Adopbers and Infected over Time
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"Adopters" 1.0 0 -10649926 true "" "plot adopters"
"Infected" 1.0 0 -8053223 true "" "plot infection"

CHOOSER
12
87
150
132
socnet?
socnet?
"random" "small-world" "scale-free" "correlated"
0

SLIDER
11
134
183
167
numsss
numsss
0
nodes * (nodes - 1) / 2
25
5
1
NIL
HORIZONTAL

SLIDER
11
208
183
241
rew-prob
rew-prob
0
1
0
0.05
1
NIL
HORIZONTAL

SLIDER
12
243
184
276
m
m
0
nodes
39
1
1
NIL
HORIZONTAL

SLIDER
11
278
183
311
prob-pref
prob-pref
0
1
1
0.05
1
NIL
HORIZONTAL

SLIDER
12
170
184
203
lattice
lattice
1
25
1
1
1
NIL
HORIZONTAL

SLIDER
422
314
594
347
timedis
timedis
0
100
1
1
1
NIL
HORIZONTAL

MONITOR
692
10
772
55
N Changes
sumchanges
17
1
11

MONITOR
267
278
333
323
conform
count socs with [learning? = \"conformist\"]
17
1
11

MONITOR
335
278
398
323
success
count socs with [learning? = \"success\"]
17
1
11

MONITOR
206
279
266
324
isolates
isolates
17
1
11

MONITOR
695
54
772
99
NIL
adopters1
17
1
11

MONITOR
597
53
693
98
N Changes Er
sumchanges1
17
1
11

MONITOR
771
310
871
355
Time Eradication
timetoerad
17
1
11

SLIDER
603
314
775
347
confid
confid
0
memory
2
1
1
NIL
HORIZONTAL

OUTPUT
887
405
1215
588
17

MONITOR
240
55
313
100
NIL
count sss
17
1
11

MONITOR
0
379
72
424
NIL
learnind1
17
1
11

MONITOR
72
379
144
424
learnind2
learnind2
17
1
11

MONITOR
-4
425
76
470
NIL
learnconf1
3
1
11

MONITOR
77
427
157
472
NIL
learnconf2
17
1
11

MONITOR
2
476
76
521
NIL
learnsuc1
17
1
11

MONITOR
77
476
151
521
NIL
learnsuc2
17
1
11

MONITOR
465
52
528
97
shortad
shortadopters
17
1
11

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="random1" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>filename</metric>
    <metric>timetoerad</metric>
    <metric>adopters1</metric>
    <metric>shortadopters</metric>
    <metric>sumchanges1</metric>
    <metric>learnind1</metric>
    <metric>learnconf1</metric>
    <metric>learnsuc1</metric>
    <metric>avgpayoff</metric>
    <metric>minpayoff</metric>
    <metric>maxpayoff</metric>
    <metric>adopters</metric>
    <metric>infection</metric>
    <metric>sumchanges</metric>
    <metric>learnind2</metric>
    <metric>learnconf2</metric>
    <metric>learnsuc2</metric>
    <enumeratedValueSet variable="resist?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resistlev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rents?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="yieldlev">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recovery">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eff">
      <value value="10"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multi">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timm">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timedis">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confid">
      <value value="0"/>
      <value value="3"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numeee">
      <value value="0"/>
      <value value="100"/>
      <value value="200"/>
      <value value="300"/>
      <value value="500"/>
      <value value="1000"/>
      <value value="2500"/>
      <value value="4950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initialinf">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="socnet?">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numsss">
      <value value="0"/>
      <value value="100"/>
      <value value="200"/>
      <value value="300"/>
      <value value="500"/>
      <value value="1000"/>
      <value value="2500"/>
      <value value="4950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learnprob">
      <value value="0"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="th">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="correlated1" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>filename</metric>
    <metric>timetoerad</metric>
    <metric>adopters1</metric>
    <metric>shortadopters</metric>
    <metric>sumchanges1</metric>
    <metric>learnind1</metric>
    <metric>learnconf1</metric>
    <metric>learnsuc1</metric>
    <metric>avgpayoff</metric>
    <metric>minpayoff</metric>
    <metric>maxpayoff</metric>
    <metric>adopters</metric>
    <metric>infection</metric>
    <metric>sumchanges</metric>
    <metric>learnind2</metric>
    <metric>learnconf2</metric>
    <metric>learnsuc2</metric>
    <enumeratedValueSet variable="resist?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resistlev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rents?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="yieldlev">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recovery">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eff">
      <value value="10"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multi">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timm">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timedis">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confid">
      <value value="0"/>
      <value value="3"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numeee">
      <value value="0"/>
      <value value="100"/>
      <value value="200"/>
      <value value="300"/>
      <value value="500"/>
      <value value="1000"/>
      <value value="2500"/>
      <value value="4950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initialinf">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="socnet?">
      <value value="&quot;correlated&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learnprob">
      <value value="0"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="th">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="smallworld1" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>filename</metric>
    <metric>timetoerad</metric>
    <metric>adopters1</metric>
    <metric>shortadopters</metric>
    <metric>sumchanges1</metric>
    <metric>learnind1</metric>
    <metric>learnconf1</metric>
    <metric>learnsuc1</metric>
    <metric>avgpayoff</metric>
    <metric>minpayoff</metric>
    <metric>maxpayoff</metric>
    <metric>adopters</metric>
    <metric>infection</metric>
    <metric>sumchanges</metric>
    <metric>learnind2</metric>
    <metric>learnconf2</metric>
    <metric>learnsuc2</metric>
    <enumeratedValueSet variable="resist?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resistlev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rents?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="yieldlev">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eff">
      <value value="10"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recovery">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multi">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timm">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timedis">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confid">
      <value value="0"/>
      <value value="3"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numeee">
      <value value="0"/>
      <value value="100"/>
      <value value="200"/>
      <value value="300"/>
      <value value="500"/>
      <value value="1000"/>
      <value value="2500"/>
      <value value="4950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initialinf">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="socnet?">
      <value value="&quot;small-world&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lattice">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="5"/>
      <value value="10"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-rew">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learnprob">
      <value value="0"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="th">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scalefree1" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>filename</metric>
    <metric>timetoerad</metric>
    <metric>adopters1</metric>
    <metric>shortadopters</metric>
    <metric>sumchanges1</metric>
    <metric>learnind1</metric>
    <metric>learnconf1</metric>
    <metric>learnsuc1</metric>
    <metric>avgpayoff</metric>
    <metric>minpayoff</metric>
    <metric>maxpayoff</metric>
    <metric>adopters</metric>
    <metric>infection</metric>
    <metric>sumchanges</metric>
    <metric>learnind2</metric>
    <metric>learnconf2</metric>
    <metric>learnsuc2</metric>
    <enumeratedValueSet variable="resist?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resistlev">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rents?">
      <value value="&quot;constant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="yieldlev">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recovery">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eff">
      <value value="10"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multi">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timm">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="timedis">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confid">
      <value value="0"/>
      <value value="3"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numeee">
      <value value="0"/>
      <value value="100"/>
      <value value="200"/>
      <value value="300"/>
      <value value="500"/>
      <value value="1000"/>
      <value value="2500"/>
      <value value="4950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initialinf">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="socnet?">
      <value value="&quot;scale-free&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="m">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="6"/>
      <value value="12"/>
      <value value="39"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-pref">
      <value value="0.6"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learnprob">
      <value value="0"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="th">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
